<?php
	/*
	Plugin Name: jQuery Pin It Button For Images
	Plugin URI: http://wordpress.org/extend/plugins/jquery-pin-it-button-for-images/
	Description: Highlights images on hover and adds a "Pin It" button over them for easy pinning.
	Author: Marcin Skrzypiec
	Version: 0.8
	Author URI: http://profiles.wordpress.org/mrsztuczkens
	*/
	
	if (!empty($_SERVER['SCRIPT_FILENAME']) && 'jquery-pin-it-button-for-images.php' == basename($_SERVER['SCRIPT_FILENAME']))
        die ('Stop! Hammer time!'); //Plugin shouldn't be accessed directly
	
	define("JPIBFI_VERSION", "0.8");
	
	if (!class_exists("jQuery_Pin_It_Button_For_Images")) {
		class jQuery_Pin_It_Button_For_Images {
		
			public static $admin_basic_options_name = "jptbfi_options";
			public static $admin_advanced_options_name = "jptbfi_advanced_options";
			public static $post_metadata_name = "jpibfi_meta";
			var $description_option_values = array ( '1', '2', '3' );
		
			//Constructor
			function jQuery_Pin_It_Button_For_Images() {}
			
			//SETTINGS VALIDATION CODE
			
			function is_string_css_class_name($class_name) {
				return 1 == preg_match( "/^-?[_a-zA-Z]+[_a-zA-Z0-9-]*$/", $class_name );
			}
			
			function contains_css_class_names_or_empty($str) {
				if ( strlen ($str ) == 0 )
					return true;

				$names = explode( ";", $str );
				$only_css_class_names = true;
				
				foreach ( $names as $name ) {
					if ( false == $this->is_string_css_class_name( $name ) ) {
						$only_css_class_names = false;
						break;
					}
				}
				return $only_css_class_names;
			}
			
			//END SETTINGS VALIDATION CODE
			
			//Returns an array of basic admin options, updates settings if necessary
			function get_basic_options() {
				$admin_options = array(
					'image_selector'     => 'div.jpibfi_container img',
					'disabled_classes'   => 'nopin;wp-smiley',
					'description_option' => '1',
					'enabled_classes'    => '',
					'compatibility_mode' => $this->description_option_values[0],
                    'transparency_value' => '0.5'
				);
				
				$dev_options = get_option( self::$admin_basic_options_name );

                $changes_in_db = count( $admin_options ) != count ( $dev_options ); //if arrays aren't of the same length, changes in db needed
				
				//invalid values need to be corrected and saved in db
				if ( ! empty( $dev_options ) ) {
					foreach ( $dev_options as $key => $option ) {
						switch ($key) {
							case "image_selector":
								$admin_options[$key] = $option;
								break;
							case "disabled_classes":
							case "enabled_classes":
								if ( $this->contains_css_class_names_or_empty( $option ) )
									$admin_options[$key] = $option;
								else
									$changes_in_db = true;
								break;
							case "description_option":
								if ( in_array( $option, $this->description_option_values ) )
									$admin_options[$key] = $option;
								else
									$changes_in_db = true;	
								break;
							case "compatibility_mode":
								if ( strcmp( $option, '0') != 0 && strcmp( $option, '1') != 0 ) //invalid value in database
									$changes_in_db = true;
								else
									$admin_options[$key] = $option;
								break;
                            case "transparency_value":
                                if ( !is_numeric( $option ) || ( $option  < 0 ) || ( $option  > 1 ) )
                                    $changes_in_db = true;
                                else
                                    $admin_options[$key] = $option;
                                break;
						}
					}
				} else {
					$changes_in_db = true;
				}

				//if something changed in the database, we need to save it
				if ( $changes_in_db )
					update_option( self::$admin_basic_options_name, $admin_options );
					
				return $admin_options;
			}//End function get_basic_options()
			
			//Returns an array of advanced admin options, updates settings if necessary
			function get_advanced_options() {
				$admin_options = array(
					'on_home'     => '1',
					'on_single'   => '1',
					'on_page'     => '1',
					'on_category' => '1'
				);
				
				$dev_options = get_option( self::$admin_advanced_options_name );
				$changes_in_db = count( $admin_options ) != count ( $dev_options ); //if arrays aren't of the same length, changes in db needed
				
				foreach ( $admin_options as $setting_name => $setting_value ) {
					if ( array_key_exists( $setting_name, $dev_options ) )
						$admin_options[$setting_name] = $dev_options[$setting_name];
				}
				
				//if something changed in the database, we need to save it
				if ( $changes_in_db )
					update_option( self::$admin_advanced_options_name, $admin_options );
				return $admin_options;
			}

            //returns false if plugin shouldn't be added to certain post based on metadata, otherwise true
            function add_plugin_to_post( $post_id ){
                $post_meta = get_post_meta( $post_id, self::$post_metadata_name, true );
                if ( !empty($post_meta) && array_key_exists( 'jpibfi_disable_for_post', $post_meta ) && $post_meta['jpibfi_disable_for_post'] == '1')
                    return false;
                return true;
            }

            //Returns true if plugin should be added to a certain page
			function add_plugin() {
				global $post;
				$advanced_settings = $this->get_advanced_options();

                if ( is_front_page() )
					return $advanced_settings['on_home'] == "1";
				else if ( is_single() )
                    return $advanced_settings['on_single'] == "1" ? $this->add_plugin_to_post( $post->ID ) : false;
				else if ( is_page() )
                    return $advanced_settings['on_page'] == "1" ? $this->add_plugin_to_post( $post->ID ) : false;
				else if ( is_category() )
					return $advanced_settings['on_category'] == "1";
				return true;
			}

			//fire it when activating the plugin - add all necessary db entries
			function init_plugin() {
				$this->get_basic_options();
				$this->get_advanced_options();
			}
			
			//Adds all necessary scripts
			function add_plugin_scripts() {
				if ( !( $this->add_plugin() ) )
					return;
					
				// Adding my custom js, dependent on jquery
				wp_enqueue_script( 'jquery-pin-it-button-script', plugins_url( '/js/script.min.js', __FILE__ ), array('jquery'), JPIBFI_VERSION, false );
				// Registering my custom style
				wp_register_style( 'jquery-pin-it-button-style', plugins_url( '/css/style.css', __FILE__ ), array(), JPIBFI_VERSION, 'all' );  
				//Enqueue the style
				wp_enqueue_style( 'jquery-pin-it-button-style');
			}
			
			function footer_action() {
				if ( !( $this->add_plugin() ) )
					return;

				$dev_options = $this->get_basic_options();
                $enabled_classes = $dev_options['enabled_classes'] ? ", enabled_classes:'" . $dev_options['enabled_classes'] . "'" : "";

				?>
				<script type="text/javascript">
					jQuery(document).ready(function($) {
						$('.jpibfi').parent('div').addClass('jpibfi_container');
						$('<?php echo $dev_options['image_selector'];?>').pinit({disabled_classes:'<?php echo $dev_options['disabled_classes'];?>', 
							description_option:'<?php echo $dev_options['description_option'];?>'<?php echo $enabled_classes;?>});
					});
				</script>
				<?php
			}
			
			function print_header_style_action() {
				if ( !( $this->add_plugin() ) )
					return;
			
				$dev_options = $this->get_basic_options();

                if ( $dev_options['compatibility_mode'] == '0' )
                    $css = 'background-color: rgba(255, 255, 255, ' . $dev_options['transparency_value']. ');';
                else
                    $css = "background: url('" .
                        plugins_url( '/images/transparency/'.
                            str_replace( '.','_', $dev_options['transparency_value'] ) . '.png', __FILE__) . "') repeat;";

				?>
				<style type="text/css">
                    .pinit .pinit-overlay { <?php echo $css; ?>	}
                </style>
				<?php
			}
			
			function print_hidden_field_script($content) {
				if ( ! $this->add_plugin() )
					return $content;
				return "<input class='jpibfi' type='hidden' />" . $content; 
			}
			
			//ADMIN PAGE CODE
			
			//add admin scripts
			function add_admin_site_scripts() {
				wp_register_style( 'jquery-pin-it-button-admin-style', plugins_url( '/css/admin.css', __FILE__ ), array(), JPIBFI_VERSION, 'all' );  
				wp_enqueue_style( 'jquery-pin-it-button-admin-style' );
				wp_enqueue_script( 'jquery-pin-it-button-script', plugins_url( '/js/admin.js', __FILE__ ), array('jquery'), JPIBFI_VERSION, false );
			}
			
			//Prints out the admin page
			function print_admin_page() {
				$dev_options = $this->get_basic_options();
				$advanced_dev_options = $this->get_advanced_options();
									
				if ( isset( $_POST['update_jQuery_Pin_It_Button_For_Images']) ) {
					//security check
					if ( !wp_verify_nonce( $_POST['jpibfi_nonce'], plugin_basename( __FILE__ ) ) )
						die( 'Security alert');
					
					$errors = array();
					
					if ( ! $this->contains_css_class_names_or_empty( $_POST['disabled_classes'] ) )
						$errors['disabled_classes'] = true;
					
					if ( ! $this->contains_css_class_names_or_empty( $_POST['enabled_classes'] ) )
						$errors['enabled_classes'] = true;
					
					//rewrite settings that came from the POST request
					$dev_options['image_selector']     = sanitize_text_field( $_POST['image_selector'] );
                    $dev_options['compatibility_mode'] = $_POST['compatibility_mode'] == '1' ? '1' : '0';
                    $dev_options['transparency_value'] =
                        $dev_options['compatibility_mode'] =='0' ? $_POST['standard_transparency'] : $_POST['compatibility_transparency'];
                    $dev_options['disabled_classes']   = $_POST['disabled_classes'];
					$dev_options['enabled_classes']    = $_POST['enabled_classes'];
					$dev_options['description_option'] = $_POST['description_option'];

                    if ($dev_options['compatibility_mode'] =='0')
                        if ( !is_numeric( $dev_options['transparency_value'] ) || ( $dev_options['transparency_value']  < 0.0 ) || ( $dev_options['transparency_value'] > 1.0 ) )
                            $errors['transparency_value'] = true;
					
					$advanced_dev_options['on_home'] = $_POST['on_home'] == '1' ? '1' : '0';
					$advanced_dev_options['on_page'] = $_POST['on_page'] == '1' ? '1' : '0';
					$advanced_dev_options['on_single'] = $_POST['on_single'] == '1' ? '1' : '0';
					$advanced_dev_options['on_category'] = $_POST['on_category'] == '1' ? '1' : '0';

					if ( 0 == count( $errors ) ) { //save only if there are no errors
						update_option( self::$admin_basic_options_name, $dev_options );
						update_option( self::$admin_advanced_options_name, $advanced_dev_options );
					?>
						<p class="jpibfi-success-message"><?php _e( "Settings Updated.", "jpibfi" );?></p>
					<?php 
					} else { //otherwise inform that there are some errors
					?>	
						<p class='jpibfi-error-message'><?php _e("Error. Settings not updated. Look for details below.", "jpibfi" ); ?></p>
					<?php
					}
				}
				?>
				<div class="wrap">
					<h2>jQuery Pin It Button For Images</h2>
					<form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
						<?php wp_nonce_field( plugin_basename( __FILE__ ), 'jpibfi_nonce' ); ?>
						<h3>Plugin settings</h3>
						
						<table class="settings-table">
							<tbody>
								<tr>
									<th scope="row"><label for="image_selector">Image selector</label></th>
									<td>
										<input type="text" id="image_selector" name="image_selector" value="<?php echo esc_attr( $dev_options['image_selector'] );?>" />
										<p class="description">jQuery selector for all the images that should have the "Pin it" button. Set the value to <a href="#" class="jpibfi_selector_option">div.jpibfi_container img</a> if you want the "Pin it" button to appear only on images in content or <a href="#" class="jpibfi_selector_option">img</a> to appear on all images on site (including sidebar, header and footer). If you know a thing or two about jQuery, you might use your own selector. <a href="http://api.jquery.com/category/selectors/" target="_blank">Click here</a> to read about jQuery selectors.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label for="disabled_classes">Disabled classes</label></th>
									<td>
										<div class="left-element">
											<textarea id="disabled_classes" name="disabled_classes" <?php if ( !empty($errors) && array_key_exists( 'disabled_classes', $errors ) ) echo "class='error-border'"; ?>><?php echo esc_attr( $dev_options['disabled_classes'] );?></textarea>
										</div>
										<div id="disabled_classes_error" class="error-info" <?php if ( !empty($errors) && array_key_exists( 'disabled_classes', $errors ) ) echo "style='display:block;'"; ?>>
											Error. Please change this setting and try submitting again.
										</div>
										<p class="description">Pictures with these CSS classes won't show the "Pin it" button. Please separate multiple classes with semicolons. Spaces are not accepted.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label for="enabled_classes">Enabled classes</label></th>
									<td>
										<div class="left-element">
											<textarea id="enabled_classes" name="enabled_classes" <?php if ( !empty($errors) && array_key_exists( 'enabled_classes', $errors ) ) echo "class='error-border'"; ?>><?php echo $dev_options['enabled_classes'];?></textarea>
										</div>
										<div id="enabled_classes_error" class="error-info" <?php if ( !empty($errors) && array_key_exists( 'enabled_classes', $errors ) ) echo "style='display:block;'"; ?>>
											Error. Please change this setting and try submitting again.
										</div>
										<p class="description">Pictures with these CSS classes will show the "Pin it" button. Please separate multiple classes with semicolons. If this field is empty, images with any (besides disabled ones) classes will show the Pin It button.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label for="description_option">Description source</label></th>
									<td>
										<select id="description_option" name="description_option">
											<option value="1" <?php if ( "1" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>Page title</option>
											<option value="2" <?php if ( "2" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>Page description</option>
											<option value="3" <?php if ( "3" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>Picture title or alt attributes</option>
										</select>
										<p class="description">From where the Pinterest message should be taken.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label for="compatibility_mode">Transparency</label></th>
									<td>
                                        <select name="compatibility_mode" id="compatibility_mode">
                                            <option value="0" <?php echo "0" == $dev_options['compatibility_mode'] ? "selected='selected'" : "";?>>Standard mode</option>
                                            <option value="1" <?php echo "1" == $dev_options['compatibility_mode'] ? "selected='selected'" : "";?>>IE7 Compatibility mode</option>
                                        </select>
                                        <p id="standard_mode_transparency" <?php echo "1" == $dev_options['compatibility_mode'] ? "style='display:none'" : "";?>>
                                            <label for="standard_transparency">Choose transparency (between 0.00 and 1.00)</label><br/>
                                            <input type="text" id="standard_transparency" name="standard_transparency" value="<?php echo $dev_options['transparency_value'];?>" <?php if ( !empty($errors) && array_key_exists( 'transparency_value', $errors ) ) echo "class='error-border'"; ?>/>
                                            <div id="standard_transparency_error" class="error-info" <?php if ( !empty($errors) && array_key_exists( 'transparency_value', $errors ) ) echo "style='display:block;'"; ?>>
                                                    The number is not valid. Please change the value and try submitting again.
                                            </div>
                                        </p>
                                        <p id="compatibility_mode_transparency" <?php echo "0" == $dev_options['compatibility_mode'] ? "style='display:none'" : "";?>>
                                            <label for="compatibility_transparency">Choose transparency</label><br/>
                                            <select name="compatibility_transparency" id="compatibility_transparency">
                                                <?php for($i = 0; $i <= 1; $i += 0.1): ?>
                                                    <option value="<?php echo $i;?>" <?php if ( round( $i, 1 ) == round( $dev_options['transparency_value'], 1 ) ) echo "selected='selected'"; ?>>
                                                        <?php echo $i;?>
                                                    </option>
                                                <?php endfor; ?>
                                            </select>
                                        </p>
                                        <!-- miejsce na odpowiednią zmieniarkę-->
										<p class="description">If you want the plugin to work properly on IE7, meaning the image will become transparent on hover, you need to use IE7 Compatibility mode.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label>One which pages the "Pin it" button should be shown</label></th>
									<td>
										<input type="checkbox" id="on_home" name="on_home" <?php echo "1" == $advanced_dev_options['on_home'] ? "checked='checked'" : "";?>" value="1" /><label class="chbox-label" for="on_home"> Home page</label><br/>
										<input type="checkbox" id="on_page" name="on_page" <?php echo "1" == $advanced_dev_options['on_page'] ? "checked='checked'" : "";?>" value="1" /><label class="chbox-label" for="on_page"> Pages</label><br/>
										<input type="checkbox" id="on_single" name="on_single" <?php echo "1" == $advanced_dev_options['on_single'] ? "checked='checked'" : "";?>" value="1" /><label class="chbox-label" for="on_single"> Single posts</label><br/>
										<input type="checkbox" id="on_category" name="on_category" <?php echo "1" == $advanced_dev_options['on_category'] ? "checked='checked'" : "";?>" value="1" /><label class="chbox-label" for="on_category"> Category pages</label>
										<p class="description">Check on which pages you want the Pinterest button to show up.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"></th>
									<td>
										<input id="submit_form" type="submit" style="padding:7px; float:right;" name="update_jQuery_Pin_It_Button_For_Images" value="<?php _e( 'Update Settings', 'jQuery_Pin_It_Button_For_Images' ) ?>" />
									</td>
								</tr>
							</tbody>
						</table>
					</form>
				 </div>
				<?php
			}//End function print_admin_page()
			
			function print_admin_page_action() {
				$page = add_options_page( 'jQuery Pin It Button For Images', 'jQuery Pin It Button For Images', 9, basename( __FILE__ ), array( $this, 'print_admin_page' ) );
				add_action( 'admin_print_styles-' . $page, array($this, 'add_admin_site_scripts' ) );
			}
			
			function plugin_settings_filter($links) { 
			  $settings_link = '<a href="options-general.php?page=jquery-pin-it-button-for-images.php">Settings</a>'; 
			  array_unshift( $links, $settings_link ); 
			  return $links; 
			}
			
			//END ADMIN PAGE CODE
			
			//POST EDITOR CODE
			
			function add_meta_box() {
				//for posts
				add_meta_box(
					'jpibfi_settings_id',          // this is HTML id of the box on edit screen
					'jQuery Pin It Button for Images - Settings',    // title of the box
					array( $this, 'print_meta_box' ),   // function to be called to display the checkboxes, see the function below
					'post',        // on which edit screen the box should appear
					'side',      // part of page where the box should appear
					'default'      // priority of the box
				);
				
				//for pages
				add_meta_box(
					'jpibfi_settings_id',
					'jQuery Pin It Button for Images - Settings',
					array( $this, 'print_meta_box' ),
					'page',
					'side',
					'default'
				);
			}

			// display the metabox
			function print_meta_box( $post, $metabox ) {
				wp_nonce_field( plugin_basename( __FILE__ ), 'jpibfi_nonce' );
				
				$post_meta = get_post_meta( $post->ID, self::$post_metadata_name, true );
				if ( isset( $post_meta ) && isset( $post_meta['jpibfi_disable_for_post'] ) && $post_meta['jpibfi_disable_for_post'] == '1' )
					$checked_message = 'checked="checked"';
				else
					$checked_message = '';
				
				echo '<input type="checkbox" id="jpibfi_disable_for_post" name="jpibfi_disable_for_post" value="1"'
					. $checked_message . ' /><label for="jpibfi_disable_for_post"> Disable "Pin it" button for this post (works only on single pages/posts)</label><br />';
			}
			
			function save_meta_data($post_id) {
				// check if this isn't an auto save
				if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
					return;
				// security check = updating possible only using post edit form
				if ( !wp_verify_nonce( $_POST['jpibfi_nonce'], plugin_basename( __FILE__ ) ) )
					return;
                //check user's permissions
                if ( !current_user_can( 'edit_post', $post_id ) )
                    return;
				
				$post_meta = array( 'jpibfi_disable_for_post' => '0' );
				// now store data in custom fields based on checkboxes selected
                $post_meta['jpibfi_disable_for_post'] =
                    isset( $_POST['jpibfi_disable_for_post'] ) && $_POST['jpibfi_disable_for_post'] == '1' ? '1' : '0';

                if ($post_meta['jpibfi_disable_for_post'] == '1')
				    update_post_meta( $post_id, self::$post_metadata_name, $post_meta );
                else
                    delete_post_meta( $post_id, self::$post_metadata_name );
			}
			//END POST EDITOR CODE
		}
	} //End Class jQuery_Pin_It_Button_For_Images
	
	if ( class_exists("jQuery_Pin_It_Button_For_Images") )
		$jptbfi_instance = new jQuery_Pin_It_Button_For_Images();

    //fire it when the plugin is deleted
    function jpibfi_uninstall_plugin() {

        //delete all added options
        delete_option(jQuery_Pin_It_Button_For_Images::$admin_basic_options_name);
        delete_option(jQuery_Pin_It_Button_For_Images::$admin_advanced_options_name);

        //delete added metadata from all posts
        delete_post_meta_by_key(jQuery_Pin_It_Button_For_Images::$post_metadata_name);
    }

	//Actions and Filters	
	if ( isset($jptbfi_instance) ) {
		//Register
		register_activation_hook( __FILE__, array( &$jptbfi_instance, 'init_plugin' ) );
        register_uninstall_hook( __FILE__, 'jpibfi_uninstall_plugin' );
		//Actions
		add_action( 'wp_enqueue_scripts', array( &$jptbfi_instance, 'add_plugin_scripts' ) );
		add_action( 'admin_menu', array( &$jptbfi_instance, 'print_admin_page_action' ) );
		add_action( 'wp_footer', array( &$jptbfi_instance, 'footer_action' ) );
		add_action( 'wp_head', array( &$jptbfi_instance, 'print_header_style_action' ) );
		add_action( 'add_meta_boxes', array( &$jptbfi_instance, 'add_meta_box' ) );
		add_action( 'save_post', array( &$jptbfi_instance, 'save_meta_data' ) );
		
		//Filters
		$plugin = plugin_basename( __FILE__ ); 
		add_filter( "plugin_action_links_$plugin", array( &$jptbfi_instance, 'plugin_settings_filter' ) );
		add_filter( "the_content", array( &$jptbfi_instance, 'print_hidden_field_script' ) );
	}

?>